@@ -23,7 +23,8 @@
 #include "error.h"
 #include "table.h"
 #include "text.h"
-#include "token.h"
+#include "textset.h"
+#include "typemap.h"
 #include "symtab.h"
 #include "datatype.h"
 #include "data.h"
