@@ -27,7 +27,8 @@
 #include "filebuf.h"
 #include "table.h"
 #include "text.h"
-#include "token.h"
+#include "textset.h"
+#include "typemap.h"
 #include "symtab.h"
 #include "datatype.h"
 #include "data.h"
