@@ -14,8 +14,8 @@
  * limitations under the License.
  */
 
-#ifndef SENTSCAN_H
-#define SENTSCAN_H
+#ifndef CORPUS_SENTSCAN_H
+#define CORPUS_SENTSCAN_H
 
 /**
  * \file sentscan.h
@@ -29,14 +29,14 @@
 /**
  * A sentence break type.
  */
-enum sent_type {
-	SENT_NONE = -1,	/**< break at the end of the text */
-	SENT_PARASEP,	/**< break after a paragraph separator */
-	SENT_ATERM,	/**< break after a full stop (.) or other
-			  ambiguous terminator */
-	SENT_STERM	/**< break after a sentence terminator
-			  like a question or exclamation
-			  mark (? or !) */
+enum corpus_sent_type {
+	CORPUS_SENT_NONE = -1,	/**< break at the end of the text */
+	CORPUS_SENT_PARASEP,	/**< break after a paragraph separator */
+	CORPUS_SENT_ATERM,	/**< break after a full stop (.) or other
+				  ambiguous terminator */
+	CORPUS_SENT_STERM	/**< break after a sentence terminator
+				  like a question or exclamation
+				  mark (? or !) */
 };
 
 /**
@@ -49,8 +49,8 @@ enum sent_type {
  * [demo]: http://unicode.org/cldr/utility/breaks.jsp
  * [uax29]: http://unicode.org/reports/tr29/
  */
-struct sentscan {
-	struct text text;	/**< the input text */
+struct corpus_sentscan {
+	struct corpus_text text;/**< the input text */
 	size_t text_attr;	/**< the input text attributes */
 
 	uint32_t code;		/**< next code point */
@@ -58,13 +58,13 @@ struct sentscan {
 	int prop;		/**< next code's sentence break property */
 	const uint8_t *ptr;	/**< next code's start */
 
-	struct text_iter iter;	/**< an iterator over the input,
-				  positioned past next code */
+	struct corpus_text_iter iter;	/**< an iterator over the input,
+					  positioned past next code */
 	int iter_prop;		/**< iterator code's sentence break property */
 	const uint8_t *iter_ptr;/**< iterator code's start */
 
-	struct text current;	/**< the current word */
-	enum sent_type type;	/**< the type of the current sentence */
+	struct corpus_text current;	/**< the current word */
+	enum corpus_sent_type type;	/**< the type of the current sentence */
 	int at_end;		/**< whether the scanner is at the end of
 				  the text */
 };
@@ -75,7 +75,8 @@ struct sentscan {
  * \param scan the scanner to initialize
  * \param text the text
  */
-void sentscan_make(struct sentscan *scan, const struct text *text);
+void corpus_sentscan_make(struct corpus_sentscan *scan,
+			  const struct corpus_text *text);
 
 /**
  * Advance a scanner to the next sentence.
@@ -84,13 +85,13 @@ void sentscan_make(struct sentscan *scan, const struct text *text);
  *
  * \returns nonzero on success, zero if at the end of the text
  */
-int sentscan_advance(struct sentscan *scan);
+int corpus_sentscan_advance(struct corpus_sentscan *scan);
 
 /**
  * Reset a scanner to the beginning of the text.
  *
  * \param scan the scanner
  */
-void sentscan_reset(struct sentscan *scan);
+void corpus_sentscan_reset(struct corpus_sentscan *scan);
 
-#endif /* SENTSCAN_H */
+#endif /* CORPUS_SENTSCAN_H */
