@@ -14,11 +14,11 @@
  * limitations under the License.
  */
 
-#ifndef UNICODE_H
-#define UNICODE_H
+#ifndef CORPUS_UNICODE_H
+#define CORPUS_UNICODE_H
 
 /**
- * \file
+ * \file unicode.h
  *
  * Unicode handling.
  */
@@ -27,63 +27,65 @@
 #include <stdint.h>
 
 /** Unicode replacement character */
-#define UNICODE_REPLACEMENT	0xFFFD
+#define CORPUS_UNICODE_REPLACEMENT	0xFFFD
 
 /** Last valid unicode codepoint */
-#define UNICODE_MAX 0x10FFFF
+#define CORPUS_UNICODE_MAX 0x10FFFF
 
 /** Number of bytes in the UTF-8 encoding of a valid unicode codepoint. */
-#define UTF8_ENCODE_LEN(u) \
+#define CORPUS_UTF8_ENCODE_LEN(u) \
 	((u) <= 0x7F     ? 1 : \
 	 (u) <= 0x07FF   ? 2 : \
 	 (u) <= 0xFFFF   ? 3 : 4)
 
 /** Number of 16-bit code units in the UTF-16 encoding of a valid unicode
  *  codepoint */
-#define UTF16_ENCODE_LEN(u) \
+#define CORPUS_UTF16_ENCODE_LEN(u) \
 	((u) <= 0xFFFF ? 1 : 2)
 
 /** High (leading) UTF-16 surrogate for a code point in the supplementary
  *  plane (U+10000 to U+10FFFF). */
-#define UTF16_HIGH(u) \
+#define CORPUS_UTF16_HIGH(u) \
 	0xD800 | (((u) - 0x010000) >> 10)
 
 /** Low (trailing) UTF-16 surrogate for a code point in the supplementary
  *  plane (U+10000 to U+10FFFF). */
-#define UTF16_LOW(u) \
+#define CORPUS_UTF16_LOW(u) \
 	0xDC00 | (((u) - 0x010000) & 0x03FF)
 
 /** Indicates whether a 16-bit code unit is a UTF-16 high surrogate.
  *  High surrogates are in the range 0xD800 `(1101 1000 0000 0000)`
  *  to 0xDBFF `(1101 1011 1111 1111)`. */
-#define IS_UTF16_HIGH(x) (((x) & 0xFC00) == 0xD800)
+#define CORPUS_IS_UTF16_HIGH(x) (((x) & 0xFC00) == 0xD800)
 
 /** Indicates whether a 16-bit code unit is a UTF-16 low surrogate.
  *  Low surrogates are in the range 0xDC00 `(1101 1100 0000 0000)`
  *  to 0xDFFF `(1101 1111 1111 1111)`. */
-#define IS_UTF16_LOW(x) (((x) & 0xFC00) == 0xDC00)
+#define CORPUS_IS_UTF16_LOW(x) (((x) & 0xFC00) == 0xDC00)
 
 /** Given the high and low UTF-16 surrogates, compute the unicode codepoint. */
-#define DECODE_UTF16_PAIR(h, l) \
+#define CORPUS_DECODE_UTF16_PAIR(h, l) \
 	(((((h) & 0x3FF) << 10) | ((l) & 0x3FF)) + 0x10000)
 
 /** Given the first byte in a valid UTF-8 byte sequence, determine the number of
  *  continuation bytes */
-#define UTF8_TAIL_LEN(x) \
+#define CORPUS_UTF8_TAIL_LEN(x) \
 	(  ((x) & 0x80) == 0x00 ? 0 \
 	 : ((x) & 0xE0) == 0xC0 ? 1 \
 	 : ((x) & 0xF0) == 0xE0 ? 2 : 3)
 
 /** Maximum number of UTF-8 continuation bytes in a valid encoded character */
-#define UTF8_TAIL_MAX 3
+#define CORPUS_UTF8_TAIL_MAX 3
 
 /** Indicates whether a given unsigned integer is a valid ASCII codepoint */
-#define IS_ASCII(x) \
+#define CORPUS_IS_ASCII(x) \
 	((x) <= 0x7F)
 
 /** Indicates whether a given unsigned integer is a valid unicode codepoint */
-#define IS_UNICODE(x) \
-	(((x) <= UNICODE_MAX) && !IS_UTF16_HIGH(x) && !IS_UTF16_LOW(x))
+#define CORPUS_IS_UNICODE(x) \
+	(((x) <= CORPUS_UNICODE_MAX) \
+	 && !CORPUS_IS_UTF16_HIGH(x) \
+	 && !CORPUS_IS_UTF16_LOW(x))
 
 /**
  * Validate the first character in a UTF-8 character buffer.
@@ -95,7 +97,7 @@
  *
  * \returns 0 on success
  */
-int scan_utf8(const uint8_t **bufptr, const uint8_t *end);
+int corpus_scan_utf8(const uint8_t **bufptr, const uint8_t *end);
 
 /**
  * Decode the first codepoint from a UTF-8 character buffer.
@@ -105,74 +107,84 @@ int scan_utf8(const uint8_t **bufptr, const uint8_t *end);
  * 	the buffer
  * \param codeptr on exit, the first codepoint in the buffer
  */
-void decode_utf8(const uint8_t **bufptr, uint32_t *codeptr);
+void corpus_decode_utf8(const uint8_t **bufptr, uint32_t *codeptr);
 
 /**
  * Encode a codepoint into a UTF-8 character buffer. The codepoint must
- * be a valid unicode character (according to #IS_UNICODE) and the buffer
- * must have space for at least #UTF8_ENCODE_LEN bytes.
+ * be a valid unicode character (according to #CORPUS_IS_UNICODE) and the buffer
+ * must have space for at least #CORPUS_UTF8_ENCODE_LEN bytes.
  *
  * \param code the codepoint
  * \param bufptr on input, a pointer to the start of the buffer;
  * 	on exit, a pointer to the end of the encoded codepoint
  */
-void encode_utf8(uint32_t code, uint8_t **bufptr);
+void corpus_encode_utf8(uint32_t code, uint8_t **bufptr);
 
 /**
  * Unicode character decomposition mappings. The compatibility mappings are
  * defined in [UAX #44 Sec. 5.7.3 Character Decomposition Maps]
  * (http://www.unicode.org/reports/tr44/#Character_Decomposition_Mappings).
  */
-enum udecomp_type {
-	UDECOMP_NORMAL = 0,          /**< normalization (required for NFD) */
-	UDECOMP_FONT = (1 << 0),     /**< font variant */
-	UDECOMP_NOBREAK = (1 << 1),  /**< no-break version of a space or hyphen */
-	UDECOMP_INITIAL = (1 << 2),  /**< initial presentation form (Arabic) */
-	UDECOMP_MEDIAL = (1 << 3),   /**< medial presentation form (Arabic) */
-	UDECOMP_FINAL = (1 << 4),    /**< final presentation form (Arabic) */
-	UDECOMP_ISOLATED = (1 << 5), /**< isolated presentation form (Arabic) */
-	UDECOMP_CIRCLE = (1 << 6),   /**< encircled form */
-	UDECOMP_SUPER = (1 << 7),    /**< superscript form */
-	UDECOMP_SUB = (1 << 8),      /**< subscript form */
-	UDECOMP_VERTICAL = (1 << 9), /**< vertical layout presentation form */
-	UDECOMP_WIDE = (1 << 10),    /**< wide (or zenkaku) compatibility */
-	UDECOMP_NARROW = (1 << 11),  /**< narrow (or hankaku) compatibility */
-	UDECOMP_SMALL = (1 << 12),   /**< small variant form (CNS compatibility) */
-	UDECOMP_SQUARE = (1 << 13),  /**< CJK squared font variant */
-	UDECOMP_FRACTION = (1 << 14),/**< vulgar fraction form */
-	UDECOMP_COMPAT = (1 << 15),  /**< unspecified compatibility */
+enum corpus_udecomp_type {
+	CORPUS_UDECOMP_NORMAL = 0, /**< normalization (required for NFD) */
+	CORPUS_UDECOMP_FONT = (1 << 0),     /**< font variant */
+	CORPUS_UDECOMP_NOBREAK = (1 << 1),  /**< no-break version of a space
+					      or hyphen */
+	CORPUS_UDECOMP_INITIAL = (1 << 2),  /**< initial presentation form
+					      (Arabic) */
+	CORPUS_UDECOMP_MEDIAL = (1 << 3),   /**< medial presentation form
+					      (Arabic) */
+	CORPUS_UDECOMP_FINAL = (1 << 4),    /**< final presentation form
+					      (Arabic) */
+	CORPUS_UDECOMP_ISOLATED = (1 << 5), /**< isolated presentation form
+					      (Arabic) */
+	CORPUS_UDECOMP_CIRCLE = (1 << 6),   /**< encircled form */
+	CORPUS_UDECOMP_SUPER = (1 << 7),    /**< superscript form */
+	CORPUS_UDECOMP_SUB = (1 << 8),      /**< subscript form */
+	CORPUS_UDECOMP_VERTICAL = (1 << 9), /**< vertical layout presentation
+					      form */
+	CORPUS_UDECOMP_WIDE = (1 << 10),    /**< wide (or zenkaku)
+					      compatibility */
+	CORPUS_UDECOMP_NARROW = (1 << 11),  /**< narrow (or hankaku)
+					      compatibility */
+	CORPUS_UDECOMP_SMALL = (1 << 12),   /**< small variant form
+					      (CNS compatibility) */
+	CORPUS_UDECOMP_SQUARE = (1 << 13),  /**< CJK squared font variant */
+	CORPUS_UDECOMP_FRACTION = (1 << 14),/**< vulgar fraction form */
+	CORPUS_UDECOMP_COMPAT = (1 << 15),  /**< unspecified compatibility */
 
-	UDECOMP_ALL = ((1 << 16) - 1)/**< all decompositions (required for NFKD) */
+	CORPUS_UDECOMP_ALL = ((1 << 16) - 1)/**< all decompositions
+					      (required for NFKD) */
 };
 
 /**
  * Unicode case folding. These are defined in *TR44* Sec. 5.6.
  */
-enum ucasefold_type {
-	UCASEFOLD_NONE = 0,		/**< do not perform any case folding */
-	UCASEFOLD_ALL = (1 << 16)	/**< perform case folding */
+enum corpus_ucasefold_type {
+	CORPUS_UCASEFOLD_NONE = 0,		/**< no case folding */
+	CORPUS_UCASEFOLD_ALL = (1 << 16)	/**< perform case folding */
 };
 
 /**
  * Maximum size (in codepoints) of a single code point's decomposition.
  *
- * From *TR44* Sec. 5.7.3: "Compatibility mappings are guaranteed to be no longer
- * than 18 characters, although most consist of just a few characters."
+ * From *TR44* Sec. 5.7.3: "Compatibility mappings are guaranteed to be no
+ * longer than 18 characters, although most consist of just a few characters."
  */
-#define UNICODE_DECOMP_MAX 18
+#define CORPUS_UNICODE_DECOMP_MAX 18
 
 /**
  * Apply decomposition and/or casefold mapping to a Unicode character,
  * outputting the result to the specified buffer. The output will be at
- * most #UNICODE_DECOMP_MAX codepoints.
+ * most #CORPUS_UNICODE_DECOMP_MAX codepoints.
  *
- * \param type a bitmask composed from #udecomp_type and #ucasefold_type
- * 	values specifying the mapping type
+ * \param type a bitmask composed from #corpus_udecomp_type and
+ * 	#corpus_ucasefold_type values specifying the mapping type
  * \param code the input codepoint
  * \param bufptr on entry, a pointer to the output buffer; on exit,
  * 	a pointer past the last output codepoint
  */
-void unicode_map(int type, uint32_t code, uint32_t **bufptr);
+void corpus_unicode_map(int type, uint32_t code, uint32_t **bufptr);
 
 /**
  * Apply the canonical ordering algorithm to put an array of Unicode
@@ -181,7 +193,7 @@ void unicode_map(int type, uint32_t code, uint32_t **bufptr);
  * \param ptr a pointer to the first codepoint
  * \param len the number of codepoints
  */
-void unicode_order(uint32_t *ptr, size_t len);
+void corpus_unicode_order(uint32_t *ptr, size_t len);
 
 /**
  * Apply the canonical composition algorithm to put an array of
@@ -191,6 +203,6 @@ void unicode_order(uint32_t *ptr, size_t len);
  * \param lenptr on entry, a pointer to the number of input codepoints;
  * 	on exit, a pointer to the number of composed codepoints
  */
-void unicode_compose(uint32_t *ptr, size_t *lenptr);
+void corpus_unicode_compose(uint32_t *ptr, size_t *lenptr);
 
-#endif /* UNICODE_H */
+#endif /* CORPUS_UNICODE_H */
