@@ -106,7 +106,7 @@ void setup_normalization(void)
 	uint32_t *dst;
 	unsigned *lenp;
 	char *comment;
-	char ch;
+	int ch;
 
 	file = fopen(NORMALIZATION_TEST, "r");
 	if (!file) {
@@ -134,7 +134,7 @@ void setup_normalization(void)
 		case '#':
 			comment = &test->comment[0];
 			do {
-				*comment++ = ch;
+				*comment++ = (char)ch;
 				ch = fgetc(file);
 			} while (ch != EOF && ch != '\n');
 			*comment = '\0';
@@ -222,7 +222,7 @@ int is_utf8(const char *str, size_t len)
         int err;
 
         while (ptr < end) {
-                if ((err = scan_utf8(&ptr, end))) {
+                if ((err = corpus_scan_utf8(&ptr, end))) {
 			return 0;
                 }
         }
@@ -390,14 +390,14 @@ static void roundtrip(uint32_t code)
 	uint32_t decode;
 
 	ptr = buf;
-	encode_utf8(code, &ptr);
+	corpus_encode_utf8(code, &ptr);
 
-	ck_assert_int_eq(ptr - buf, UTF8_ENCODE_LEN(code));
-	ck_assert(is_utf8((const char *)buf, UTF8_ENCODE_LEN(code)));
+	ck_assert_int_eq(ptr - buf, CORPUS_UTF8_ENCODE_LEN(code));
+	ck_assert(is_utf8((const char *)buf, CORPUS_UTF8_ENCODE_LEN(code)));
 
 	ptr = buf;
-	decode_utf8((const uint8_t **)&ptr, &decode);
-	ck_assert_int_eq(ptr - buf, UTF8_ENCODE_LEN(code));
+	corpus_decode_utf8((const uint8_t **)&ptr, &decode);
+	ck_assert_int_eq(ptr - buf, CORPUS_UTF8_ENCODE_LEN(code));
 	ck_assert_int_eq(code, decode);
 }
 
@@ -407,8 +407,8 @@ START_TEST(test_encode_decode_utf8)
 	uint32_t code;
 
 	// U+0000..U+FFFF
-	for (code = 0; code <= 0xFFFF; code++) {
-		if (!IS_UNICODE(code)) {
+	for (code = 0; code <= 0xFFFF; code += 0xFF) {
+		if (!CORPUS_IS_UNICODE(code)) {
 			continue;
 		}
 		roundtrip(code);
@@ -435,73 +435,7 @@ START_TEST(test_encode_decode_utf8)
 END_TEST
 
 
-START_TEST(test_normalize_nfd)
-{
-	unsigned i, n = num_normalization_test;
-	unsigned j, len;
-	struct normalization_test *test;
-	uint32_t buf[128];
-	uint32_t *dst;
-	uint32_t code;
-
-	for (i = 0; i < n; i++) {
-		test = &normalization_tests[i];
-		dst = buf;
-		for (j = 0; j < test->source_len; j++) {
-			code = test->source[j];
-			unicode_map(0, code, &dst);
-		}
-
-		len = dst - buf;
-		ck_assert_int_eq(len, test->nfd_len);
-
-		unicode_order(buf, len);
-
-		for (j = 0; j < test->nfd_len; j++) {
-			if (buf[j] != test->nfd[j]) {
-				write_normalization_test(stderr, test);
-			}
-			ck_assert_uint_eq(buf[j], test->nfd[j]);
-		}
-	}
-}
-END_TEST
-
-
-START_TEST(test_normalize_nfkd)
-{
-	unsigned i, n = num_normalization_test;
-	unsigned j, len;
-	struct normalization_test *test;
-	uint32_t buf[128];
-	uint32_t *dst;
-	uint32_t code;
-
-	for (i = 0; i < n; i++) {
-		test = &normalization_tests[i];
-		dst = buf;
-		for (j = 0; j < test->source_len; j++) {
-			code = test->source[j];
-			unicode_map(UDECOMP_ALL, code, &dst);
-		}
-
-		len = dst - buf;
-		ck_assert_int_eq(len, test->nfkd_len);
-
-		unicode_order(buf, len);
-
-		for (j = 0; j < test->nfkd_len; j++) {
-			if (buf[j] != test->nfkd[j]) {
-				write_normalization_test(stderr, test);
-			}
-			ck_assert_uint_eq(buf[j], test->nfkd[j]);
-		}
-	}
-}
-END_TEST
-
-
-START_TEST(test_normalize_nfc)
+START_TEST(test_normalize_nfc_nfd)
 {
 	unsigned i, n = num_normalization_test;
 	size_t j, len;
@@ -515,14 +449,22 @@ START_TEST(test_normalize_nfc)
 		dst = buf;
 		for (j = 0; j < test->source_len; j++) {
 			code = test->source[j];
-			unicode_map(0, code, &dst);
+			corpus_unicode_map(0, code, &dst);
 		}
-		len = dst - buf;
 
-		unicode_order(buf, len);
-		unicode_compose(buf, &len);
+		len = (size_t)(dst - buf);
+		ck_assert_int_eq(len, test->nfd_len);
 
-		ck_assert_int_eq(len, test->nfc_len);
+		corpus_unicode_order(buf, len);
+		for (j = 0; j < test->nfd_len; j++) {
+			if (buf[j] != test->nfd[j]) {
+				write_normalization_test(stderr, test);
+			}
+			ck_assert_uint_eq(buf[j], test->nfd[j]);
+		}
+
+		corpus_unicode_compose(buf, &len);
+		ck_assert_uint_eq(len, test->nfc_len);
 
 		for (j = 0; j < test->nfc_len; j++) {
 			if (buf[j] != test->nfc[j]) {
@@ -535,7 +477,7 @@ START_TEST(test_normalize_nfc)
 END_TEST
 
 
-START_TEST(test_normalize_nfkc)
+START_TEST(test_normalize_nfkc_nfkd)
 {
 	unsigned i, n = num_normalization_test;
 	size_t j, len;
@@ -549,14 +491,23 @@ START_TEST(test_normalize_nfkc)
 		dst = buf;
 		for (j = 0; j < test->source_len; j++) {
 			code = test->source[j];
-			unicode_map(UDECOMP_ALL, code, &dst);
+			corpus_unicode_map(CORPUS_UDECOMP_ALL, code, &dst);
 		}
-		len = dst - buf;
 
-		unicode_order(buf, len);
-		unicode_compose(buf, &len);
+		len = (size_t)(dst - buf);
+		ck_assert_int_eq(len, test->nfkd_len);
 
-		ck_assert_int_eq(len, test->nfkc_len);
+		corpus_unicode_order(buf, len);
+
+		for (j = 0; j < test->nfkd_len; j++) {
+			if (buf[j] != test->nfkd[j]) {
+				write_normalization_test(stderr, test);
+			}
+			ck_assert_uint_eq(buf[j], test->nfkd[j]);
+		}
+
+		corpus_unicode_compose(buf, &len);
+		ck_assert_uint_eq(len, test->nfkc_len);
 
 		for (j = 0; j < test->nfkc_len; j++) {
 			if (buf[j] != test->nfkc[j]) {
@@ -564,6 +515,7 @@ START_TEST(test_normalize_nfkc)
 			}
 			ck_assert_uint_eq(buf[j], test->nfkc[j]);
 		}
+
 	}
 }
 END_TEST
@@ -594,10 +546,8 @@ Suite *unicode_suite(void)
 	tc = tcase_create("utf32 normalization");
 	tcase_add_checked_fixture(tc, setup_normalization,
 				  teardown_normalization);
-	tcase_add_test(tc, test_normalize_nfd);
-	tcase_add_test(tc, test_normalize_nfkd);
-	tcase_add_test(tc, test_normalize_nfc);
-	tcase_add_test(tc, test_normalize_nfkc);
+	tcase_add_test(tc, test_normalize_nfc_nfd);
+	tcase_add_test(tc, test_normalize_nfkc_nfkd);
 	suite_add_tcase(s, tc);
 
 	return s;
