@@ -7,10 +7,10 @@ test_that("converting to list works", {
     file <- tempfile()
     writeLines(paste0('{"x":', x, ',"y":"', y, '"}'), file)
 
-    ds <- read_ndjson(file)
+    ds <- read_ndjson(file, stringsAsFactors = FALSE)
     l <- as.list(ds)
 
-    expect_equal(l, list(x=x, y=as_text(y)))
+    expect_equal(l, list(x=x, y=y))
 
     rm("ds", "l"); gc(); file.remove(file)
 })
